<style>
  .md-sidebar--secondary .md-nav__list .md-nav__list .md-nav__list .md-nav__list {
    display: none
  }
  .md-typeset h5 {
    text-transform: none;
  }
</style>
::: thehive4py.types
    options:
        show_submodules: true